summaryrefslogtreecommitdiffstats
path: root/chrome/browser/importer
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-15 19:41:09 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-15 19:41:09 +0000
commita945841f6a3c2adcabe2a830f0c9e0b18e1574ac (patch)
tree1cd7c14dea0b982d1869dbc5c4a280e3875b4734 /chrome/browser/importer
parent162b5998f0e5caa333d9f348207b7f5a649f8eac (diff)
downloadchromium_src-a945841f6a3c2adcabe2a830f0c9e0b18e1574ac.zip
chromium_src-a945841f6a3c2adcabe2a830f0c9e0b18e1574ac.tar.gz
chromium_src-a945841f6a3c2adcabe2a830f0c9e0b18e1574ac.tar.bz2
fav icon -> favicon. Pass 9: chrome/browser/history
BUG=76073 TEST=none; no visible change Review URL: http://codereview.chromium.org/6696027 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@78261 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/importer')
-rw-r--r--chrome/browser/importer/external_process_importer_client.cc2
-rw-r--r--chrome/browser/importer/external_process_importer_client.h6
-rw-r--r--chrome/browser/importer/firefox2_importer.cc8
-rw-r--r--chrome/browser/importer/firefox2_importer.h4
-rw-r--r--chrome/browser/importer/firefox3_importer.cc6
-rw-r--r--chrome/browser/importer/firefox3_importer.h2
-rw-r--r--chrome/browser/importer/importer_bridge.cc4
-rw-r--r--chrome/browser/importer/importer_bridge.h6
-rw-r--r--chrome/browser/importer/importer_host.h2
-rw-r--r--chrome/browser/importer/importer_messages.h10
-rw-r--r--chrome/browser/importer/importer_unittest.cc4
-rw-r--r--chrome/browser/importer/profile_writer.cc2
-rw-r--r--chrome/browser/importer/profile_writer.h4
-rw-r--r--chrome/browser/importer/safari_importer.h2
-rw-r--r--chrome/browser/importer/safari_importer.mm6
-rw-r--r--chrome/browser/importer/safari_importer_unittest.mm6
16 files changed, 37 insertions, 37 deletions
diff --git a/chrome/browser/importer/external_process_importer_client.cc b/chrome/browser/importer/external_process_importer_client.cc
index a4ddeee..250b47c 100644
--- a/chrome/browser/importer/external_process_importer_client.cc
+++ b/chrome/browser/importer/external_process_importer_client.cc
@@ -201,7 +201,7 @@ void ExternalProcessImporterClient::OnFavIconsImportStart(
}
void ExternalProcessImporterClient::OnFavIconsImportGroup(
- const std::vector<history::ImportedFavIconUsage>& favicons_group) {
+ const std::vector<history::ImportedFaviconUsage>& favicons_group) {
if (cancelled_)
return;
diff --git a/chrome/browser/importer/external_process_importer_client.h b/chrome/browser/importer/external_process_importer_client.h
index 540cf65..2f1d93e 100644
--- a/chrome/browser/importer/external_process_importer_client.h
+++ b/chrome/browser/importer/external_process_importer_client.h
@@ -19,7 +19,7 @@ class InProcessImporterBridge;
namespace history {
class URLRow;
-struct ImportedFavIconUsage;
+struct ImportedFaviconUsage;
}
namespace importer {
@@ -97,7 +97,7 @@ class ExternalProcessImporterClient
// Called when a group of favicons has been received.
virtual void OnFavIconsImportGroup(
- const std::vector<history::ImportedFavIconUsage>& favicons_group)
+ const std::vector<history::ImportedFaviconUsage>& favicons_group)
OVERRIDE;
// Called when the passwordform has been received.
@@ -117,7 +117,7 @@ class ExternalProcessImporterClient
// entire group has been collected and is ready to be written to the profile.
std::vector<history::URLRow> history_rows_;
std::vector<ProfileWriter::BookmarkEntry> bookmarks_;
- std::vector<history::ImportedFavIconUsage> favicons_;
+ std::vector<history::ImportedFaviconUsage> favicons_;
// Usually some variation on IDS_BOOKMARK_GROUP_...; the name of the folder
// under which imported bookmarks will be placed.
diff --git a/chrome/browser/importer/firefox2_importer.cc b/chrome/browser/importer/firefox2_importer.cc
index d180ea1..bf2f128 100644
--- a/chrome/browser/importer/firefox2_importer.cc
+++ b/chrome/browser/importer/firefox2_importer.cc
@@ -144,7 +144,7 @@ void Firefox2Importer::ImportBookmarksFile(
Importer* importer,
std::vector<ProfileWriter::BookmarkEntry>* bookmarks,
std::vector<TemplateURL*>* template_urls,
- std::vector<history::ImportedFavIconUsage>* favicons) {
+ std::vector<history::ImportedFaviconUsage>* favicons) {
std::string content;
file_util::ReadFileToString(file_path, &content);
std::vector<std::string> lines;
@@ -289,7 +289,7 @@ void Firefox2Importer::ImportBookmarks() {
// Parse the bookmarks.html file.
std::vector<ProfileWriter::BookmarkEntry> bookmarks, toolbar_bookmarks;
std::vector<TemplateURL*> template_urls;
- std::vector<history::ImportedFavIconUsage> favicons;
+ std::vector<history::ImportedFaviconUsage> favicons;
FilePath file = source_path_;
if (!parsing_bookmarks_html_file_)
file = file.AppendASCII("bookmarks.html");
@@ -654,7 +654,7 @@ void Firefox2Importer::FindXMLFilesInDir(
void Firefox2Importer::DataURLToFaviconUsage(
const GURL& link_url,
const GURL& favicon_data,
- std::vector<history::ImportedFavIconUsage>* favicons) {
+ std::vector<history::ImportedFaviconUsage>* favicons) {
if (!link_url.is_valid() || !favicon_data.is_valid() ||
!favicon_data.SchemeIs(chrome::kDataScheme))
return;
@@ -665,7 +665,7 @@ void Firefox2Importer::DataURLToFaviconUsage(
data.empty())
return;
- history::ImportedFavIconUsage usage;
+ history::ImportedFaviconUsage usage;
if (!ReencodeFavicon(reinterpret_cast<const unsigned char*>(&data[0]),
data.size(), &usage.png_data))
return; // Unable to decode.
diff --git a/chrome/browser/importer/firefox2_importer.h b/chrome/browser/importer/firefox2_importer.h
index 253e585..42a9da2 100644
--- a/chrome/browser/importer/firefox2_importer.h
+++ b/chrome/browser/importer/firefox2_importer.h
@@ -51,7 +51,7 @@ class Firefox2Importer : public Importer {
Importer* importer,
std::vector<ProfileWriter::BookmarkEntry>* bookmarks,
std::vector<TemplateURL*>* template_urls,
- std::vector<history::ImportedFavIconUsage>* favicons);
+ std::vector<history::ImportedFaviconUsage>* favicons);
private:
FRIEND_TEST_ALL_PREFIXES(FirefoxImporterTest, Firefox2BookmarkParse);
@@ -136,7 +136,7 @@ class Firefox2Importer : public Importer {
static void DataURLToFaviconUsage(
const GURL& link_url,
const GURL& favicon_data,
- std::vector<history::ImportedFavIconUsage>* favicons);
+ std::vector<history::ImportedFaviconUsage>* favicons);
FilePath source_path_;
FilePath app_path_;
diff --git a/chrome/browser/importer/firefox3_importer.cc b/chrome/browser/importer/firefox3_importer.cc
index 8c5b656..bd5244f 100644
--- a/chrome/browser/importer/firefox3_importer.cc
+++ b/chrome/browser/importer/firefox3_importer.cc
@@ -299,7 +299,7 @@ void Firefox3Importer::ImportBookmarks() {
STLDeleteContainerPointers(template_urls.begin(), template_urls.end());
}
if (!favicon_map.empty() && !cancelled()) {
- std::vector<history::ImportedFavIconUsage> favicons;
+ std::vector<history::ImportedFaviconUsage> favicons;
LoadFavicons(db.get(), favicon_map, &favicons);
bridge_->SetFavicons(favicons);
}
@@ -550,7 +550,7 @@ void Firefox3Importer::GetWholeBookmarkFolder(sqlite3* db, BookmarkList* list,
void Firefox3Importer::LoadFavicons(
sqlite3* db,
const FaviconMap& favicon_map,
- std::vector<history::ImportedFavIconUsage>* favicons) {
+ std::vector<history::ImportedFaviconUsage>* favicons) {
SQLStatement s;
const char* stmt = "SELECT url, data FROM moz_favicons WHERE id=?";
if (s.prepare(db, stmt) != SQLITE_OK)
@@ -560,7 +560,7 @@ void Firefox3Importer::LoadFavicons(
i != favicon_map.end(); ++i) {
s.bind_int64(0, i->first);
if (s.step() == SQLITE_ROW) {
- history::ImportedFavIconUsage usage;
+ history::ImportedFaviconUsage usage;
usage.favicon_url = GURL(s.column_string(0));
if (!usage.favicon_url.is_valid())
diff --git a/chrome/browser/importer/firefox3_importer.h b/chrome/browser/importer/firefox3_importer.h
index fbe2ea5..799ad28 100644
--- a/chrome/browser/importer/firefox3_importer.h
+++ b/chrome/browser/importer/firefox3_importer.h
@@ -70,7 +70,7 @@ class Firefox3Importer : public Importer {
// and converts it into FaviconUsage structures.
void LoadFavicons(sqlite3* db,
const FaviconMap& favicon_map,
- std::vector<history::ImportedFavIconUsage>* favicons);
+ std::vector<history::ImportedFaviconUsage>* favicons);
FilePath source_path_;
FilePath app_path_;
diff --git a/chrome/browser/importer/importer_bridge.cc b/chrome/browser/importer/importer_bridge.cc
index 39b95d5..d68cc16 100644
--- a/chrome/browser/importer/importer_bridge.cc
+++ b/chrome/browser/importer/importer_bridge.cc
@@ -58,7 +58,7 @@ void InProcessImporterBridge::AddIE7PasswordInfo(
#endif // OS_WIN
void InProcessImporterBridge::SetFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons) {
+ const std::vector<history::ImportedFaviconUsage>& favicons) {
BrowserThread::PostTask(
BrowserThread::UI, FROM_HERE,
NewRunnableMethod(writer_, &ProfileWriter::AddFavicons, favicons));
@@ -152,7 +152,7 @@ void ExternalProcessImporterBridge::AddIE7PasswordInfo(
#endif
void ExternalProcessImporterBridge::SetFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons) {
+ const std::vector<history::ImportedFaviconUsage>& favicons) {
profile_import_thread_->NotifyFavIconsImportReady(favicons);
}
diff --git a/chrome/browser/importer/importer_bridge.h b/chrome/browser/importer/importer_bridge.h
index 32f7e1c..d0b980c 100644
--- a/chrome/browser/importer/importer_bridge.h
+++ b/chrome/browser/importer/importer_bridge.h
@@ -34,7 +34,7 @@ class ImporterBridge : public base::RefCountedThreadSafe<ImporterBridge> {
#endif
virtual void SetFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons) = 0;
+ const std::vector<history::ImportedFaviconUsage>& favicons) = 0;
virtual void SetHistoryItems(const std::vector<history::URLRow> &rows,
history::VisitSource visit_source) = 0;
virtual void SetKeywords(const std::vector<TemplateURL*> &template_urls,
@@ -92,7 +92,7 @@ class InProcessImporterBridge : public ImporterBridge {
#endif
virtual void SetFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons);
+ const std::vector<history::ImportedFaviconUsage>& favicons);
virtual void SetHistoryItems(const std::vector<history::URLRow> &rows,
history::VisitSource visit_source);
virtual void SetKeywords(const std::vector<TemplateURL*>& template_urls,
@@ -138,7 +138,7 @@ class ExternalProcessImporterBridge : public ImporterBridge {
#endif
virtual void SetFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons);
+ const std::vector<history::ImportedFaviconUsage>& favicons);
virtual void SetHistoryItems(const std::vector<history::URLRow> &rows,
history::VisitSource visit_source);
virtual void SetKeywords(const std::vector<TemplateURL*>& template_urls,
diff --git a/chrome/browser/importer/importer_host.h b/chrome/browser/importer/importer_host.h
index 9082973..d092d26 100644
--- a/chrome/browser/importer/importer_host.h
+++ b/chrome/browser/importer/importer_host.h
@@ -32,7 +32,7 @@ class TemplateURL;
namespace history {
class URLRow;
-struct ImportedFavIconUsage;
+struct ImportedFaviconUsage;
}
namespace importer {
diff --git a/chrome/browser/importer/importer_unittest.cc b/chrome/browser/importer/importer_unittest.cc
index c66f5e2..d5c40e2 100644
--- a/chrome/browser/importer/importer_unittest.cc
+++ b/chrome/browser/importer/importer_unittest.cc
@@ -655,7 +655,7 @@ class FirefoxObserver : public ProfileWriter,
STLDeleteContainerPointers(template_urls.begin(), template_urls.end());
}
- void AddFavicons(const std::vector<history::ImportedFavIconUsage>& favicons) {
+ void AddFavicons(const std::vector<history::ImportedFaviconUsage>& favicons) {
}
private:
@@ -865,7 +865,7 @@ class Firefox3Observer : public ProfileWriter,
STLDeleteContainerPointers(template_urls.begin(), template_urls.end());
}
- void AddFavicons(const std::vector<history::ImportedFavIconUsage>& favicons) {
+ void AddFavicons(const std::vector<history::ImportedFaviconUsage>& favicons) {
}
private:
diff --git a/chrome/browser/importer/profile_writer.cc b/chrome/browser/importer/profile_writer.cc
index 4d921a5..5bc5f63 100644
--- a/chrome/browser/importer/profile_writer.cc
+++ b/chrome/browser/importer/profile_writer.cc
@@ -152,7 +152,7 @@ void ProfileWriter::AddBookmarkEntry(
}
void ProfileWriter::AddFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons) {
+ const std::vector<history::ImportedFaviconUsage>& favicons) {
profile_->GetFaviconService(Profile::EXPLICIT_ACCESS)->
SetImportedFavicons(favicons);
}
diff --git a/chrome/browser/importer/profile_writer.h b/chrome/browser/importer/profile_writer.h
index 3002b1a..838c87b 100644
--- a/chrome/browser/importer/profile_writer.h
+++ b/chrome/browser/importer/profile_writer.h
@@ -21,7 +21,7 @@ class TemplateURL;
struct IE7PasswordInfo;
namespace history {
-struct ImportedFavIconUsage;
+struct ImportedFaviconUsage;
class URLRow;
}
@@ -95,7 +95,7 @@ class ProfileWriter : public base::RefCountedThreadSafe<ProfileWriter> {
const std::wstring& first_folder_name,
int options);
virtual void AddFavicons(
- const std::vector<history::ImportedFavIconUsage>& favicons);
+ const std::vector<history::ImportedFaviconUsage>& favicons);
// Add the TemplateURLs in |template_urls| to the local store and make the
// TemplateURL at |default_keyword_index| the default keyword (does not set
// a default keyword if it is -1). The local store becomes the owner of the
diff --git a/chrome/browser/importer/safari_importer.h b/chrome/browser/importer/safari_importer.h
index 84d10d6a..9def59f 100644
--- a/chrome/browser/importer/safari_importer.h
+++ b/chrome/browser/importer/safari_importer.h
@@ -95,7 +95,7 @@ class SafariImporter : public Importer {
// Loads and reencodes the individual favicons.
void LoadFaviconData(sqlite3* db,
const FaviconMap& favicon_map,
- std::vector<history::ImportedFavIconUsage>* favicons);
+ std::vector<history::ImportedFaviconUsage>* favicons);
FilePath library_dir_;
diff --git a/chrome/browser/importer/safari_importer.mm b/chrome/browser/importer/safari_importer.mm
index fa5135f..e5a90d8 100644
--- a/chrome/browser/importer/safari_importer.mm
+++ b/chrome/browser/importer/safari_importer.mm
@@ -118,7 +118,7 @@ void SafariImporter::ImportBookmarks() {
ImportFavIconURLs(db.get(), &favicon_map);
// Write favicons into profile.
if (!favicon_map.empty() && !cancelled()) {
- std::vector<history::ImportedFavIconUsage> favicons;
+ std::vector<history::ImportedFaviconUsage> favicons;
LoadFaviconData(db.get(), favicon_map, &favicons);
bridge_->SetFavicons(favicons);
}
@@ -156,7 +156,7 @@ void SafariImporter::ImportFavIconURLs(sqlite3* db, FaviconMap* favicon_map) {
void SafariImporter::LoadFaviconData(sqlite3* db,
const FaviconMap& favicon_map,
- std::vector<history::ImportedFavIconUsage>* favicons) {
+ std::vector<history::ImportedFaviconUsage>* favicons) {
SQLStatement s;
const char* stmt = "SELECT i.url, d.data "
"FROM IconInfo i JOIN IconData d "
@@ -169,7 +169,7 @@ void SafariImporter::LoadFaviconData(sqlite3* db,
i != favicon_map.end(); ++i) {
s.bind_int64(0, i->first);
if (s.step() == SQLITE_ROW) {
- history::ImportedFavIconUsage usage;
+ history::ImportedFaviconUsage usage;
usage.favicon_url = GURL(s.column_string(0));
if (!usage.favicon_url.is_valid())
diff --git a/chrome/browser/importer/safari_importer_unittest.mm b/chrome/browser/importer/safari_importer_unittest.mm
index 8323517..d8cd209 100644
--- a/chrome/browser/importer/safari_importer_unittest.mm
+++ b/chrome/browser/importer/safari_importer_unittest.mm
@@ -120,13 +120,13 @@ TEST_F(SafariImporterTest, FavIconImport) {
SafariImporter::FaviconMap favicon_map;
importer->ImportFavIconURLs(db.get(), &favicon_map);
- std::vector<history::ImportedFavIconUsage> favicons;
+ std::vector<history::ImportedFaviconUsage> favicons;
importer->LoadFaviconData(db.get(), favicon_map, &favicons);
size_t num_favicons = favicons.size();
ASSERT_EQ(num_favicons, 2U);
- history::ImportedFavIconUsage &fav0 = favicons[0];
+ history::ImportedFaviconUsage &fav0 = favicons[0];
EXPECT_EQ("http://s.ytimg.com/yt/favicon-vfl86270.ico",
fav0.favicon_url.spec());
EXPECT_GT(fav0.png_data.size(), 0U);
@@ -134,7 +134,7 @@ TEST_F(SafariImporterTest, FavIconImport) {
EXPECT_TRUE(fav0.urls.find(GURL("http://www.youtube.com/"))
!= fav0.urls.end());
- history::ImportedFavIconUsage &fav1 = favicons[1];
+ history::ImportedFaviconUsage &fav1 = favicons[1];
EXPECT_EQ("http://www.opensearch.org/favicon.ico",
fav1.favicon_url.spec());
EXPECT_GT(fav1.png_data.size(), 0U);
diff --git a/chrome/browser/importer/importer_messages.h b/chrome/browser/importer/importer_messages.h
index 62cd05b..9c17039 100644
--- a/chrome/browser/importer/importer_messages.h
+++ b/chrome/browser/importer/importer_messages.h
@@ -162,10 +162,10 @@ struct ParamTraits<ProfileWriter::BookmarkEntry> {
}
}; // ParamTraits<ProfileWriter::BookmarkEntry>
// Traits for history::ImportedFavIconUsage.
template <>
-struct ParamTraits<history::ImportedFavIconUsage> {
- typedef history::ImportedFavIconUsage param_type;
+struct ParamTraits<history::ImportedFaviconUsage> {
+ typedef history::ImportedFaviconUsage param_type;
static void Write(Message* m, const param_type& p) {
WriteParam(m, p.favicon_url);
WriteParam(m, p.png_data);
@@ -186,7 +186,7 @@ struct ParamTraits<history::ImportedFavIconUsage> {
LogParam(p.urls, l);
l->append(")");
}
-}; // ParamTraits<history::ImportedFavIconUsage
+}; // ParamTraits<history::ImportedFaviconUsage
// Traits for TemplateURLRef
template <>
@@ -425,7 +425,7 @@ IPC_MESSAGE_CONTROL1(ProfileImportProcessHostMsg_NotifyFavIconsImportStart,
int /* total number of FavIcons */)
IPC_MESSAGE_CONTROL1(ProfileImportProcessHostMsg_NotifyFavIconsImportGroup,
- std::vector<history::ImportedFavIconUsage> )
+ std::vector<history::ImportedFaviconUsage> )
IPC_MESSAGE_CONTROL1(ProfileImportProcessHostMsg_NotifyPasswordFormReady,
webkit_glue::PasswordForm )
@@ -162,10 +162,10 @@ struct ParamTraits<ProfileWriter::BookmarkEntry> {
}
}; // ParamTraits<ProfileWriter::BookmarkEntry>
-// Traits for history::ImportedFavIconUsage.
+// Traits for history::ImportedFaviconUsage.
template <>